@@ -32,7 +32,8 @@
 #define HAVE_PROTOTYPES 1
 #define TOKEN_PASTE(x,y) x##y
 #define HAVE_STDARG_PROTOTYPES 1
-#define NORETURN(x) x __attribute__ ((noreturn))
+#define NORETURN(x) __attribute__ ((noreturn)) x
+#define NOINLINE(x) __attribute__ ((noinline)) x
 #define HAVE_DECL_SYS_NERR 1
 #define HAVE_DIRENT_H 1
 #define STDC_HEADERS 1
@@ -160,10 +161,11 @@
 #define STACK_GROW_DIRECTION -1
 #define DEFAULT_KCODE KCODE_NONE
 #define USE_ELF 1
+#define DLEXT_MAXLEN 3
 #define DLEXT ".so"
 #define RUBY_LIB "/usr/local/lib/ruby/1.8"
 #define RUBY_SITE_LIB "/usr/local/lib/ruby/site_ruby"
 #define RUBY_SITE_LIB2 "/usr/local/lib/ruby/site_ruby/1.8"
-#define RUBY_PLATFORM "alpha-openbsd4.2"
-#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.8/alpha-openbsd4.2"
-#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.8/alpha-openbsd4.2"
+#define RUBY_PLATFORM "alpha-openbsd4.3"
+#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.8/alpha-openbsd4.3"
+#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.8/alpha-openbsd4.3"
