@@ -1,4 +1,3 @@
-
 #define PACKAGE_NAME ""
 #define PACKAGE_TARNAME ""
 #define PACKAGE_VERSION ""
@@ -33,7 +32,8 @@
 #define HAVE_PROTOTYPES 1
 #define TOKEN_PASTE(x,y) x##y
 #define HAVE_STDARG_PROTOTYPES 1
-#define NORETURN(x) x __attribute__ ((noreturn))
+#define NORETURN(x) __attribute__ ((noreturn)) x
+#define NOINLINE(x) __attribute__ ((noinline)) x
 #define HAVE_DECL_SYS_NERR 1
 #define HAVE_DIRENT_H 1
 #define STDC_HEADERS 1
@@ -61,6 +61,7 @@
 #define HAVE_FLOAT_H 1
 #define HAVE_IEEEFP_H 1
 #define HAVE_PTHREAD_H 1
+#define SIZEOF_RLIM_T 8
 #define HAVE_STRUCT_STAT_ST_BLKSIZE 1
 #define HAVE_ST_BLKSIZE 1
 #define HAVE_STRUCT_STAT_ST_BLOCKS 1
@@ -127,6 +128,8 @@
 #define HAVE_SETGROUPS 1
 #define HAVE_GETPRIORITY 1
 #define HAVE_GETRLIMIT 1
+#define HAVE_SETRLIMIT 1
+#define HAVE_SYSCONF 1
 #define HAVE_DLOPEN 1
 #define HAVE_SIGPROCMASK 1
 #define HAVE_SIGACTION 1
@@ -142,6 +145,8 @@
 #define HAVE_TANH 1
 #define HAVE_SETUID 1
 #define HAVE_SETGID 1
+#define HAVE_SETENV 1
+#define HAVE_UNSETENV 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
@@ -152,13 +157,15 @@
 #define FILE_COUNT _r
 #define FILE_READPTR _p
 #define NEED_IO_SEEK_BETWEEN_RW 1
+#define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
 #define DEFAULT_KCODE KCODE_NONE
 #define USE_ELF 1
+#define DLEXT_MAXLEN 3
 #define DLEXT ".so"
 #define RUBY_LIB "/usr/local/lib/ruby/1.8"
 #define RUBY_SITE_LIB "/usr/local/lib/ruby/site_ruby"
 #define RUBY_SITE_LIB2 "/usr/local/lib/ruby/site_ruby/1.8"
-#define RUBY_PLATFORM "arm-openbsd3.9"
-#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.8/arm-openbsd3.9"
-#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.8/arm-openbsd3.9"
+#define RUBY_PLATFORM "arm-openbsd4.3"
+#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.8/arm-openbsd4.3"
+#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.8/arm-openbsd4.3"
