@@ -3,14 +3,14 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module Config
-  RUBY_VERSION == "1.8.4" or
-    raise "ruby lib version (1.8.4) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "1.8.6" or
+    raise "ruby lib version (1.8.6) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.8/arm-openbsd4.0")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.8/arm-openbsd4.3")
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
-  CONFIG["INSTALL"] = "/usr/bin/install -c -o root -g bin"
+  CONFIG["INSTALL"] = '/usr/bin/install -c -o root -g bin'
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["EXEEXT"] = ""
   CONFIG["ruby_install_name"] = "ruby"
@@ -27,50 +27,61 @@ module Config
   CONFIG["bindir"] = "$(exec_prefix)/bin"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
-  CONFIG["datadir"] = "$(prefix)/share"
+  CONFIG["datarootdir"] = "$(prefix)/share"
+  CONFIG["datadir"] = "$(datarootdir)"
   CONFIG["sysconfdir"] = "$(DESTDIR)/etc"
   CONFIG["sharedstatedir"] = "$(prefix)/com"
   CONFIG["localstatedir"] = "$(prefix)/var"
-  CONFIG["libdir"] = "$(exec_prefix)/lib"
   CONFIG["includedir"] = "$(prefix)/include"
   CONFIG["oldincludedir"] = "/usr/include"
+  CONFIG["docdir"] = "$(datarootdir)/doc/$(PACKAGE)"
   CONFIG["infodir"] = "$(DESTDIR)/usr/local/info"
+  CONFIG["htmldir"] = "$(docdir)"
+  CONFIG["dvidir"] = "$(docdir)"
+  CONFIG["pdfdir"] = "$(docdir)"
+  CONFIG["psdir"] = "$(docdir)"
+  CONFIG["libdir"] = "$(exec_prefix)/lib"
+  CONFIG["localedir"] = "$(datarootdir)/locale"
   CONFIG["mandir"] = "$(DESTDIR)/usr/local/man"
+  CONFIG["ECHO_C"] = ""
+  CONFIG["ECHO_N"] = "-n"
+  CONFIG["ECHO_T"] = ""
+  CONFIG["LIBS"] = "-lm "
   CONFIG["build_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["target_alias"] = ""
-  CONFIG["ECHO_C"] = "\\c"
-  CONFIG["ECHO_N"] = ""
-  CONFIG["ECHO_T"] = ""
-  CONFIG["LIBS"] = "-lm "
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "8"
-  CONFIG["TEENY"] = "4"
-  CONFIG["build"] = "arm-unknown-openbsd4.0"
+  CONFIG["TEENY"] = "6"
+  CONFIG["build"] = "arm-unknown-openbsd4.3"
   CONFIG["build_cpu"] = "arm"
   CONFIG["build_vendor"] = "unknown"
-  CONFIG["build_os"] = "openbsd4.0"
-  CONFIG["host"] = "arm-unknown-openbsd4.0"
+  CONFIG["build_os"] = "openbsd4.3"
+  CONFIG["host"] = "arm-unknown-openbsd4.3"
   CONFIG["host_cpu"] = "arm"
   CONFIG["host_vendor"] = "unknown"
-  CONFIG["host_os"] = "openbsd4.0"
-  CONFIG["target"] = "arm-unknown-openbsd4.0"
+  CONFIG["host_os"] = "openbsd4.3"
+  CONFIG["target"] = "arm-unknown-openbsd4.3"
   CONFIG["target_cpu"] = "arm"
   CONFIG["target_vendor"] = "unknown"
-  CONFIG["target_os"] = "openbsd4.0"
+  CONFIG["target_os"] = "openbsd4.3"
   CONFIG["CC"] = "cc"
   CONFIG["CFLAGS"] = "-O2 -pipe  -fPIC"
-  CONFIG["LDFLAGS"] = " -Wl,-E"
-  CONFIG["CPPFLAGS"] = ""
+  CONFIG["LDFLAGS"] = "-L.  -Wl,-E"
+  CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPP"] = "cc -E"
-  CONFIG["EGREP"] = "grep -E"
+  CONFIG["GREP"] = "/usr/bin/grep"
+  CONFIG["EGREP"] = "/usr/bin/grep -E"
   CONFIG["GNU_LD"] = "yes"
   CONFIG["CPPOUTFILE"] = "-o conftest.i"
   CONFIG["OUTFLAG"] = "-o "
   CONFIG["YACC"] = "yacc"
+  CONFIG["YFLAGS"] = ""
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["AR"] = "ar"
+  CONFIG["AS"] = "as"
+  CONFIG["ASFLAGS"] = ""
   CONFIG["NM"] = ""
   CONFIG["WINDRES"] = ""
   CONFIG["DLLWRAP"] = ""
@@ -83,7 +94,6 @@ module Config
   CONFIG["RM"] = "rm -f"
   CONFIG["CP"] = "cp"
   CONFIG["MAKEDIRS"] = "mkdir -p"
-  CONFIG["LIBOBJS"] = ""
   CONFIG["ALLOCA"] = ""
   CONFIG["DLDFLAGS"] = ""
   CONFIG["ARCH_FLAG"] = ""
@@ -108,18 +118,18 @@ module Config
   CONFIG["ARCHFILE"] = ""
   CONFIG["RDOCTARGET"] = ""
   CONFIG["XCFLAGS"] = " -DRUBY_EXPORT"
-  CONFIG["XLDFLAGS"] = " -L."
+  CONFIG["XLDFLAGS"] = ""
   CONFIG["LIBRUBY_LDSHARED"] = "$(CC) -shared  -fPIC"
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
   CONFIG["rubyw_install_name"] = ""
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.1.84"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.1.86"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static"
-  CONFIG["LIBRUBYARG_SHARED"] = "-Wl,-R -Wl,$(libdir) -L$(libdir) -L. -l$(RUBY_SO_NAME)"
+  CONFIG["LIBRUBYARG_SHARED"] = "-Wl,-R -Wl,$(libdir) -L$(libdir) -l$(RUBY_SO_NAME)"
   CONFIG["SOLIBS"] = "$(LIBS)"
   CONFIG["DLDLIBS"] = " -lc"
   CONFIG["ENABLE_SHARED"] = "yes"
@@ -128,15 +138,13 @@ module Config
   CONFIG["COMMON_MACROS"] = ""
   CONFIG["COMMON_HEADERS"] = ""
   CONFIG["EXPORT_PREFIX"] = ""
-  CONFIG["MINIOBJS"] = ""
   CONFIG["MAKEFILES"] = "Makefile"
-  CONFIG["arch"] = "arm-openbsd4.0"
-  CONFIG["sitearch"] = "arm-openbsd4.0"
+  CONFIG["arch"] = "arm-openbsd4.3"
+  CONFIG["sitearch"] = "arm-openbsd4.3"
   CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
-  CONFIG["configure_args"] = "'--enable-shared' '--enable-ipv6' '--with-dbm-type=bogus' '--with-opt-dir=/usr/local' '--with-tcl-include=/usr/local/include/tcl8.4' '--with-tk-include=/usr/local/include/tk8.4' '--with-X11-dir=/usr/X11R6' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' 'CC=cc' 'CFLAGS=-O2 -pipe'"
+  CONFIG["configure_args"] = " '--enable-shared' '--enable-ipv6' '--with-dbm-type=bogus' '--with-opt-dir=/usr/local' '--with-tcl-include=/usr/local/include/tcl8.4' '--with-tk-include=/usr/local/include/tk8.4' '--with-X11-dir=/usr/X11R6' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' 'CC=cc' 'CFLAGS=-O2 -pipe' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE' 'YACC=yacc'"
   CONFIG["NROFF"] = "/usr/bin/nroff"
   CONFIG["MANTYPE"] = "doc"
-  CONFIG["LTLIBOBJS"] = ""
   CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
   CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
@@ -166,4 +174,5 @@ module Config
     Config::expand(val)
   end
 end
+RbConfig = Config # compatibility for ruby-1.9
 CROSS_COMPILING = nil unless defined? CROSS_COMPILING
