@@ -3,10 +3,10 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module Config
-  RUBY_VERSION == "1.8.5" or
-    raise "ruby lib version (1.8.5) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "1.8.6" or
+    raise "ruby lib version (1.8.6) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.8/i386-openbsd4.2")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/1.8/i386-openbsd4.3")
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
@@ -52,22 +52,22 @@ module Config
   CONFIG["target_alias"] = ""
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "8"
-  CONFIG["TEENY"] = "5"
-  CONFIG["build"] = "i386-unknown-openbsd4.2"
+  CONFIG["TEENY"] = "6"
+  CONFIG["build"] = "i386-unknown-openbsd4.3"
   CONFIG["build_cpu"] = "i386"
   CONFIG["build_vendor"] = "unknown"
-  CONFIG["build_os"] = "openbsd4.2"
-  CONFIG["host"] = "i386-unknown-openbsd4.2"
+  CONFIG["build_os"] = "openbsd4.3"
+  CONFIG["host"] = "i386-unknown-openbsd4.3"
   CONFIG["host_cpu"] = "i386"
   CONFIG["host_vendor"] = "unknown"
-  CONFIG["host_os"] = "openbsd4.2"
-  CONFIG["target"] = "i386-unknown-openbsd4.2"
+  CONFIG["host_os"] = "openbsd4.3"
+  CONFIG["target"] = "i386-unknown-openbsd4.3"
   CONFIG["target_cpu"] = "i386"
   CONFIG["target_vendor"] = "unknown"
-  CONFIG["target_os"] = "openbsd4.2"
+  CONFIG["target_os"] = "openbsd4.3"
   CONFIG["CC"] = "cc"
   CONFIG["CFLAGS"] = "-O2 -pipe  -fPIC"
-  CONFIG["LDFLAGS"] = " -Wl,-E"
+  CONFIG["LDFLAGS"] = "-L.  -Wl,-E"
   CONFIG["CPPFLAGS"] = "-DOPENSSL_NO_STATIC_ENGINE"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPP"] = "cc -E"
@@ -94,7 +94,6 @@ module Config
   CONFIG["RM"] = "rm -f"
   CONFIG["CP"] = "cp"
   CONFIG["MAKEDIRS"] = "mkdir -p"
-  CONFIG["LIBOBJS"] = ""
   CONFIG["ALLOCA"] = ""
   CONFIG["DLDFLAGS"] = ""
   CONFIG["ARCH_FLAG"] = ""
@@ -119,18 +118,18 @@ module Config
   CONFIG["ARCHFILE"] = ""
   CONFIG["RDOCTARGET"] = ""
   CONFIG["XCFLAGS"] = " -DRUBY_EXPORT"
-  CONFIG["XLDFLAGS"] = " -L."
+  CONFIG["XLDFLAGS"] = ""
   CONFIG["LIBRUBY_LDSHARED"] = "$(CC) -shared  -fPIC"
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
   CONFIG["rubyw_install_name"] = ""
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.1.85"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.1.86"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static"
-  CONFIG["LIBRUBYARG_SHARED"] = "-Wl,-R -Wl,$(libdir) -L$(libdir) -L. -l$(RUBY_SO_NAME)"
+  CONFIG["LIBRUBYARG_SHARED"] = "-Wl,-R -Wl,$(libdir) -L$(libdir) -l$(RUBY_SO_NAME)"
   CONFIG["SOLIBS"] = "$(LIBS)"
   CONFIG["DLDLIBS"] = " -lc"
   CONFIG["ENABLE_SHARED"] = "yes"
@@ -139,16 +138,13 @@ module Config
   CONFIG["COMMON_MACROS"] = ""
   CONFIG["COMMON_HEADERS"] = ""
   CONFIG["EXPORT_PREFIX"] = ""
-  CONFIG["MINIOBJS"] = ""
-  CONFIG["PREINSTALL"] = ""
   CONFIG["MAKEFILES"] = "Makefile"
-  CONFIG["arch"] = "i386-openbsd4.2"
-  CONFIG["sitearch"] = "i386-openbsd4.2"
+  CONFIG["arch"] = "i386-openbsd4.3"
+  CONFIG["sitearch"] = "i386-openbsd4.3"
   CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
   CONFIG["configure_args"] = " '--enable-shared' '--enable-ipv6' '--with-dbm-type=bogus' '--with-opt-dir=/usr/local' '--with-tcl-include=/usr/local/include/tcl8.4' '--with-tk-include=/usr/local/include/tk8.4' '--with-X11-dir=/usr/X11R6' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' 'CC=cc' 'CFLAGS=-O2 -pipe' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE' 'YACC=yacc'"
   CONFIG["NROFF"] = "/usr/bin/nroff"
   CONFIG["MANTYPE"] = "doc"
-  CONFIG["LTLIBOBJS"] = ""
   CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
   CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
